# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['pythonit_toolkit',
 'pythonit_toolkit.api',
 'pythonit_toolkit.emails',
 'pythonit_toolkit.emails.backends',
 'pythonit_toolkit.headers',
 'pythonit_toolkit.pastaporto',
 'pythonit_toolkit.sentry',
 'pythonit_toolkit.starlette_backend']

package_data = \
{'': ['*']}

install_requires = \
['PyJWT>=2.0.1,<3.0.0',
 'boto3>=1.17.39,<2.0.0',
 'sentry-sdk>=1.1.0,<2.0.0',
 'strawberry-graphql']

setup_kwargs = {
    'name': 'pythonit-toolkit',
    'version': '0.1.54.dev1628185083',
    'description': '',
    'long_description': None,
    'author': 'Python Italia',
    'author_email': None,
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)



from typing import Any

import jwt


def decode_pastaporto(token: str, secret: str) -> dict[str, Any]:
    return jwt.decode(
        token,
        str(secret),
        issuer="gateway",
        algorithms=["HS256"],
        options={"require": ["exp", "iss", "iat"]},
    )


def decode_service_to_service_token(
    token: str, secret: str, *, issuer: str, audience: str
):
    return jwt.decode(
        token,
        secret,
        verify=True,
        audience=audience,
        issuer=issuer,
        algorithms=["HS256"],
        options={"require": ["exp", "iss", "aud", "iat"]},
    )



import json
from typing import Optional

import boto3
from pythonit_toolkit.emails.templates import EmailTemplate

from .base import EmailBackend


class SESEmailBackend(EmailBackend):
    def __init__(self, environment: str) -> None:
        super().__init__(environment)
        self.ses = boto3.client("ses")

    def send_email(
        self,
        *,
        template: EmailTemplate,
        subject: str,
        from_: str,
        to: str,
        variables: Optional[dict[str, str]] = None,
    ):
        variables = {"subject": subject, **(variables or {})}
        self.ses.send_templated_email(
            Source=from_,
            Destination={"ToAddresses": [to]},
            Template=f"pythonit-{self.environment}-{template}",
            TemplateData=json.dumps(variables),
        )



from sentry_sdk import add_breadcrumb
from strawberry.extensions import Extension
from strawberry.types.execution import ExecutionContext


class SentryExtension(Extension):
    def on_request_start(self, execution_context: ExecutionContext):
        add_breadcrumb(
            category="graphql",
            message=f"""
{execution_context.operation_name or 'No operation name'}
{execution_context.query}
            """.strip(),
            level="info",
        )
